@@ -1,7 +1,7 @@
 /*
    Handle so called 'shell archives'.
 
-   Copyright (C) 1994-1996, 2002, 2005-2007, 2010-2011
+   Copyright (C) 1994-2013
       Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
@@ -21,16 +21,11 @@
 #ifndef SHARUTILS_LOCAL_H
 #define SHARUTILS_LOCAL_H 1
 
-#ifdef HAVE_CONFIG_H
-# include <config.h>
-#endif
-
-#ifndef USE_UNLOCKED_IO
-#  define USE_UNLOCKED_IO 1
-#endif
-
+#include "system.h"
 #include <alloca.h>
+#include <ctype.h>
 #include <getopt.h>
+#include <stddef.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -38,16 +33,17 @@
 #include <time.h>
 #include <unistd.h>
 
-#include "basename.h"
+#include "base64.h"
 #include "dirname.h"
 #include "error.h"
 #include "gettext.h"
+#include "idcache.h"
 #include "inttostr.h"
 #include "locale.h"
+#include "md5.h"
 #include "pathmax.h"
 #include "quotearg.h"
 #include "strftime.h"
-#include "system.h"
 #include "unlocked-io.h"
 #include "xalloc.h"
 #include "xgetcwd.h"
